@@ -1,7 +1,5 @@
 /*
  * Functions used across the program.
- *
- * Copyright 2014 Andrew Wood, distributed under the Artistic License 2.0.
  */
 
 #ifndef _PV_H
@@ -63,12 +61,13 @@ extern pvstate_t pv_state_alloc(const char *);
 /*
  * Set the formatting string, given a set of old-style formatting options.
  */
-extern void pv_state_set_format(pvstate_t, unsigned char progress,
-			 unsigned char timer, unsigned char eta,
-			 unsigned char rate, unsigned char average_rate,
-			 unsigned char bytes, unsigned char bufpercent,
-			 unsigned int lastwritten,
-			 const char *name);
+extern void pv_state_set_format(pvstate_t state, unsigned char progress,
+				unsigned char timer, unsigned char eta,
+				unsigned char fineta, unsigned char rate,
+				unsigned char average_rate, unsigned char bytes,
+				unsigned char bufpercent,
+				unsigned int lastwritten,
+				const char *name);
 
 /*
  * Set the various options.
@@ -77,6 +76,7 @@ extern void pv_state_force_set(pvstate_t, unsigned char);
 extern void pv_state_cursor_set(pvstate_t, unsigned char);
 extern void pv_state_numeric_set(pvstate_t, unsigned char);
 extern void pv_state_wait_set(pvstate_t, unsigned char);
+extern void pv_state_delay_start_set(pvstate_t, double);
 extern void pv_state_linemode_set(pvstate_t, unsigned char);
 extern void pv_state_null_set(pvstate_t, unsigned char);
 extern void pv_state_no_op_set(pvstate_t, unsigned char);
