@@ -1,7 +1,5 @@
 /*
  * State management functions.
- *
- * Copyright 2014 Andrew Wood, distributed under the Artistic License 2.0.
  */
 
 #include "pv-internal.h"
@@ -36,6 +34,7 @@ pvstate_t pv_state_alloc(const char *program_name)
 #ifdef HAVE_SPLICE
 	state->splice_failed_fd = -1;
 #endif				/* HAVE_SPLICE */
+	state->display_visible = 0;
 
 	return state;
 }
@@ -68,8 +67,9 @@ void pv_state_free(pvstate_t state)
  */
 void pv_state_set_format(pvstate_t state, unsigned char progress,
 			 unsigned char timer, unsigned char eta,
-			 unsigned char rate, unsigned char average_rate,
-			 unsigned char bytes, unsigned char bufpercent,
+			 unsigned char fineta, unsigned char rate,
+			 unsigned char average_rate, unsigned char bytes,
+			 unsigned char bufpercent,
 			 unsigned int lastwritten, const char *name)
 {
 #define PV_ADDFORMAT(x,y) if (x) { \
@@ -87,6 +87,7 @@ void pv_state_set_format(pvstate_t state, unsigned char progress,
 	PV_ADDFORMAT(average_rate, "%a");
 	PV_ADDFORMAT(progress, "%p");
 	PV_ADDFORMAT(eta, "%e");
+	PV_ADDFORMAT(fineta, "%I");
 	if (lastwritten > 0) {
 		char buf[16];
 		sprintf(buf, "%%%uA", lastwritten);
@@ -118,6 +119,11 @@ void pv_state_wait_set(pvstate_t state, unsigned char val)
 	state->wait = val;
 };
 
+void pv_state_delay_start_set(pvstate_t state, double val)
+{
+	state->delay_start = val;
+};
+
 void pv_state_linemode_set(pvstate_t state, unsigned char val)
 {
 	state->linemode = val;
